[prev in list] [next in list] [prev in thread] [next in thread] 

List:       squirrelmail-cvs
Subject:    [SM-CVS] SF.net SVN: squirrelmail: [12712] trunk/squirrelmail
From:       pdontthink () users ! sourceforge ! net
Date:       2007-09-29 21:57:56
Message-ID: E1IbkJw-0005Tw-RT () sc8-pr-svn2 ! sourceforge ! net
[Download RAW message or body]

Revision: 12712
          http://squirrelmail.svn.sourceforge.net/squirrelmail/?rev=12712&view=rev
Author:   pdontthink
Date:     2007-09-29 14:57:56 -0700 (Sat, 29 Sep 2007)

Log Message:
-----------
Make message list refresh work again in default advanced tempate

Modified Paths:
--------------
    trunk/squirrelmail/functions/strings.php
    trunk/squirrelmail/src/read_body.php

Modified: trunk/squirrelmail/functions/strings.php
===================================================================
--- trunk/squirrelmail/functions/strings.php	2007-09-29 18:25:07 UTC (rev 12711)
+++ trunk/squirrelmail/functions/strings.php	2007-09-29 21:57:56 UTC (rev 12712)
@@ -546,6 +546,32 @@
 
 
 /**
+ * Get Message List URI
+ *
+ * @param string $mailbox      Current mailbox name (unencoded/raw)
+ * @param string $startMessage The mailbox page offset
+ * @param string $what         Any current search parameters (OPTIONAL; 
+ *                             default empty string)
+ *
+ * @return string The message list URI
+ *
+ * @since 1.5.2
+ *
+ */
+function get_message_list_uri($mailbox, $startMessage, $what='') {
+
+    global $base_uri;
+
+    $urlMailbox = urlencode($mailbox);
+
+    $list_xtra = "?where=read_body.php&what=$what&mailbox=" . $urlMailbox.
+                 "&startMessage=$startMessage";
+
+    return $base_uri .'src/right_main.php'. $list_xtra;
+}
+
+
+/**
  * Encrypts password
  *
  * These functions are used to encrypt the password before it is

Modified: trunk/squirrelmail/src/read_body.php
===================================================================
--- trunk/squirrelmail/src/read_body.php	2007-09-29 18:25:07 UTC (rev 12711)
+++ trunk/squirrelmail/src/read_body.php	2007-09-29 21:57:56 UTC (rev 12712)
@@ -431,7 +431,7 @@
 /**
  * Format message toolbar
  *
  * @param string $mailbox Name of current mailbox
  * @param int $passed_id UID of current message
  * @param int $passed_ent_id Id of entity within message
  * @param object $message Current message object
@@ -531,11 +531,11 @@
         }
     }
 
-    // Start with Search Results or Message List link.
-    $list_xtra = "?where=read_body.php&what=$what&mailbox=" . $urlMailbox.
-                 "&startMessage=$startMessage";
-    $msg_list_href = $base_uri .'src/right_main.php'. $list_xtra;
-    $search_href = $where=='search.php' ? $base_uri .'src/search.php?'.$list_xtra : \
''; +    $msg_list_href = get_message_list_uri($aMailbox['NAME'], $startMessage, \
$what); +    if ($where == 'search.php')
+        $search_href = str_replace('read_body.php', 'search.php', $msg_list_href);
+    else
+        $search_href = '';
 
     $comp_uri = $base_uri.'src/compose.php' .
                 '?passed_id=' . $passed_id .
@@ -947,6 +947,9 @@
 sqsession_register($mailbox_cache,'mailbox_cache');
 $_SESSION['mailbox_cache'] = $mailbox_cache;
 
+// message list URI is used in page header when on read_body
+$oTemplate->assign('message_list_href', get_message_list_uri($aMailbox['NAME'], \
$startMessage, $what)); +
 displayPageHeader($color, $mailbox,'','');
 formatMenubar($aMailbox, $passed_id, $passed_ent_id, $message,false);
 formatEnvheader($aMailbox, $passed_id, $passed_ent_id, $message, $color, \
$FirstTimeSee);


This was sent by the SourceForge.net collaborative development platform, the world's \
largest Open Source development site.

-------------------------------------------------------------------------
@@ -431,7 +431,7 @@
  * Format message toolbar
  *
- * @param string $mailbox Name of current mailbox
+ * @param array $aMailbox Current mailbox information array
  * @param int $passed_id UID of current message
  * @param int $passed_ent_id Id of entity within message
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse0120000070mrt/direct/01/
--
squirrelmail-cvs mailing list
List Address: squirrelmail-cvs@lists.sourceforge.net
List Info: https://lists.sourceforge.net/lists/listinfo/squirrelmail-cvs
http://squirrelmail.org/cvs


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic